function [h,ff] = freqs(b,a,f)
%FREQS Laplace-transform (s-domain) frequency response.  
%   H = FREQS(B,A,W) returns the complex frequency response vector H 
%   of the filter B/A:
%                        nb-1         nb-2
%            B(s)   b(1)s     +  b(2)s     + ... +  b(nb)
%     H(s) = ---- = -------------------------------------
%                        na-1         na-2
%            A(s)   a(1)s     +  a(2)s     + ... +  a(na)
%
%   given the numerator and denominator coefficients in vectors B and A. 
%   The frequency response is evaluated at the points specified in 
%   vector W (in rad/s).  The magnitude and phase can be graphed by
%   calling FREQS(B,A,W) with no output arguments.
%
%   [H,W] = FREQS(B,A) automatically picks a set of 200 frequencies W on 
%   which the frequency response is computed.  FREQS(B,A,N) picks N 
%   frequencies. 
%
%   See also LOGSPACE, POLYVAL, INVFREQS, and FREQZ.

% 	Author(s): J.N. Little, 6-26-86
%   	   T. Krauss, 3-19-93, default plots and frequency vector
%   Copyright 1988-2004 The MathWorks, Inc.
%   $Revision: 1.12.4.3 $  $Date: 2007/12/14 15:04:49 $

error(nargchk(2,3,nargin,'struct'));
error(nargoutchk(0,2,nargout,'struct'));

if ~any(size(b)<=1) || ~any(size(a)<=1),
    error(generatemsgid('InvalidDimensions'),'The numerator and denominator must be vectors.');
end

if nargin < 3
    f = logspace(2,5,301);
end

s = 1j*2*pi*f;
hh = polyval(b,s) ./ polyval(a,s);

if nargout == 0,
    freqs_plot(hh,f);
elseif nargout == 1,
    h = hh;
elseif nargout == 2,
    h = hh;
    ff = f;
end
% end freqs
